@@ -15,8 +15,9 @@ public class Version {
 	/**
 	 * Paraseleneのバージョン番号を表す文字列。
 	 */
-	public static final String VERSION = "1.2.1.3";
-	private static final String	TITLE = "Paraselene  Version " + VERSION;
+	public static final String VERSION = "1.2.1.4";
+	private static final String	SITE = " (http://paraselene.sourceforge.jp/)";
+	private static final String	TITLE = "Paraselene1 " + VERSION + SITE;
 
 	/**
 	 * Paraseleneのアプリタイトル文字列。
